# pysonar-scanner
**DEPRECATION NOTICE:**

This application is no longer actively maintained and has been deprecated in favor of `pysonar`. `pysonar` offers a more Python-centric experience and support for newer versions of SonarQube.

**Please migrate to `pysonar` for all future usage.**

You can install it via pip:
`pip install pysonar`

# License

Copyright 2011-2024 SonarSource.

Licensed under the [GNU Lesser General Public License, Version 3.0](http://www.gnu.org/licenses/lgpl.txt)
